# ATE Apps Common Package

This package provides helper and utility functions that are used by the other semit-ate applications. When writing this document the following semi-ate applications do exist:

* semi-ate-master-app
* semi-ate-control-app
* semi-ate-test-app
* semi-ate-handler-app
